@@ -68,7 +68,7 @@ struct Digest {
    }
 };
 
-static constexpr Digest Digests[] = {
+static constexpr std::array<Digest,12> Digests = {{
    {Digest::State::Untrusted, "Invalid digest"},
    {Digest::State::Untrusted, "MD5"},
    {Digest::State::Untrusted, "SHA1"},
@@ -81,17 +81,14 @@ static constexpr Digest Digests[] = {
    {Digest::State::Trusted, "SHA384"},
    {Digest::State::Trusted, "SHA512"},
    {Digest::State::Trusted, "SHA224"},
-};
+}};
 
-static Digest FindDigest(std::string const & Digest)
+static Digest FindDigest(std::string const &Digest)
 {
    int id = atoi(Digest.c_str());
-   if (id >= 0 && static_cast<unsigned>(id) < APT_ARRAY_SIZE(Digests))
-   {
+   if (id >= 0 && static_cast<unsigned>(id) < Digests.size())
       return Digests[id];
-   } else {
-      return Digests[0];
-   }
+   return Digests[0];
 }
 
 struct Signer {
@@ -130,7 +127,7 @@ class GPGVMethod : public aptMethod
 				     SignersStorage &Signers);
 
    protected:
-   virtual bool URIAcquire(std::string const &Message, FetchItem *Itm) APT_OVERRIDE;
+   bool URIAcquire(std::string const &Message, FetchItem *Itm) override;
    public:
    GPGVMethod() : aptMethod("gpgv", "1.1", SingleInstance | SendConfig | SendURIEncoded){};
 };
@@ -214,7 +211,7 @@ string GPGVMethod::VerifyGetSigners(const char *file, const char *outfile,
 
    FILE *pipein = fdopen(fd[0], "r");
 
-   // Loop over the output of apt-key (which really is gnupg), and check the signatures.
+   // Loop over the output of gpgv, and check the signatures.
    std::vector<std::string> ErrSigners;
    std::map<std::string, std::vector<std::string>> SubKeyMapping;
    size_t buffersize = 0;
@@ -340,7 +337,7 @@ string GPGVMethod::VerifyGetSigners(const char *file, const char *outfile,
    for (auto errSigner : ErrSigners)
       Signers.Worthless.push_back({errSigner, ""});
 
-   // apt-key has a --keyid parameter, but this requires gpg, so we call it without it
+   // gpgv has no --keyid parameter, so we call it without it
    // and instead check after the fact which keyids where used for verification
    if (keyFpts.empty() == false)
    {
@@ -565,7 +562,7 @@ bool GPGVMethod::URIAcquire(std::string const &Message, FetchItem *Itm)
 	    keyFpts.emplace_back(std::move(key));
    }
 
-   // Run apt-key on file, extract contents and get the key ID of the signer
+   // Run gpgv on file, extract contents and get the key ID of the signer
    string const msg = VerifyGetSignersWithLegacy(Path.c_str(), Itm->DestFile.c_str(), keyFpts, keyFiles, Signers);
    if (_error->PendingError())
       return false;
@@ -660,7 +657,7 @@ bool GPGVMethod::URIAcquire(std::string const &Message, FetchItem *Itm)
    Dequeue();
 
    if (DebugEnabled())
-      std::clog << "apt-key succeeded\n";
+      std::clog << "gpgv succeeded\n";
 
    return true;
 }
